@@ -55,28 +55,42 @@ class ContractFinder:
         now = datetime.datetime.now()
 
         if now < wednesday_time:
-            return contracts_df.iloc[0]["symbol"]
+            return contracts_df.iloc[0]
         else:
             # Remove contracts with zero date difference
             contracts_df = contracts_df[contracts_df["date_diff"] != 0]
             contracts_df.reset_index(drop=True, inplace=True)
-            return contracts_df.iloc[0]["symbol"]
+            return contracts_df.iloc[0]
 
 
 class ShioajiWrapper:
     def __init__(self, api):
         self.api = api
 
+    def login(self, api_key, api_secret, contracts_timeout=10000):
+        self.api.login(api_key, api_secret, contracts_timeout=contracts_timeout)
+
+    def get_api(self):
+        return self.api
+
     def get_stock_list(self):
         stock_list = [
             s
             for stock in self.api.Contracts.Stocks
             for s in stock
-            if len(s["code"]) == 4
+            if s["symbol"][:3] != "OES" and len(s["code"]) == 4
         ]
-        code_list = [stock.code for stock in stock_list]
+        code_list = sorted([i.code for i in stock_list])
         return code_list
 
+    def get_snapshots(self, stock_list):
+        contracts_dict = self.api.Contracts.Stocks
+        contracts = [contracts_dict[i] for i in stock_list]
+        snapshots = self.api.snapshots(contracts)
+        df = pd.DataFrame(s.__dict__ for s in snapshots)
+        df.ts = pd.to_datetime(df.ts)
+        return df
+
     def get_near_month_txf_contract(self):
         contract = min(
             [
@@ -88,12 +102,13 @@ class ShioajiWrapper:
         )
         return contract
 
-    def is_market_open(self):
-        now = datetime.datetime.now()
-        contract = self.get_near_month_txf_contract()
-        update_date_str = contract.update_date
-        update_date = datetime.datetime.strptime(update_date_str, "%Y/%m/%d").date()
-        return update_date == now.date()
+    def is_trading_day(self, now=datetime.datetime.now()):
+        kbars = self.api.kbars(
+            contract=self.api.Contracts.Indexs.TSE.TSE001,
+            start=now.strftime("%Y-%m-%d"),
+            end=now.strftime("%Y-%m-%d"),
+        )
+        return len(kbars.Open) > 0
 
     def get_latest_option_contract(self):
         contract_finder = ContractFinder(self.api)
