@@ -80,14 +80,39 @@ def get_github_repo(token, repo_name):
     return repo
 
 
-def decrypt_data_from_github(filename, my_password, github_token, repo_name):
+@retry(exceptions=Exception, tries=3, delay=2, backoff=2)
+def get_github_all_files(token, repo_name, branch=None):
+    repo = get_github_repo(token=token, repo_name=repo_name)
+    all_files = []
+    if branch:
+        contents = repo.get_contents("", ref=branch)
+    else:
+        contents = repo.get_contents("")
+    while contents:
+        file_content = contents.pop(0)
+        if file_content.type == "dir":
+            if branch:
+                contents.extend(repo.get_contents(file_content.path, ref=branch))
+            else:
+                contents.extend(repo.get_contents(file_content.path))
+        else:
+            file = file_content
+            all_files.append(
+                str(file).replace('ContentFile(path="', "").replace('")', "")
+            )
+    return all_files
+
+
+def decrypt_data_from_github(
+    filename, my_password, github_token, repo_name, branch=None
+):
     repo = get_github_repo(token=github_token, repo_name=repo_name)
 
     # Create AESCrypt instance
     aes = AESCrypt(my_password)
 
     # Download encrypted file from Github
-    download_file(repo=repo, github_file_path=filename)
+    download_file(repo=repo, github_file_path=filename, branch=branch)
 
     # Read encrypted data from file
     with open(filename, "rb") as f:
@@ -103,12 +128,16 @@ def decrypt_data_from_github(filename, my_password, github_token, repo_name):
 
 
 @retry(exceptions=Exception, tries=3, delay=2, backoff=2)
-def download_file(repo, github_file_path, download_path=None):
+def download_file(repo, github_file_path, download_path=None, branch=None):
     filename = os.path.basename(github_file_path)
     if not download_path:
         download_path = os.getcwd()
 
-    file_content = repo.get_contents(github_file_path)
+    if branch:
+        file_content = repo.get_contents(github_file_path, ref=branch)
+    else:
+        file_content = repo.get_contents(github_file_path)
+
     file_content_data = file_content.decoded_content
     mode = "wb" if isinstance(file_content_data, bytes) else "w"
     with open(os.path.join(download_path, filename), mode) as f:
@@ -120,7 +149,10 @@ def download_file(repo, github_file_path, download_path=None):
 def update_file(repo, filename, branch=None):
     cwd = os.path.abspath(os.getcwd())
     try:
-        contents = repo.get_contents(filename)
+        if branch:
+            contents = repo.get_contents(filename, ref=branch)
+        else:
+            contents = repo.get_contents(filename)
         sha = contents.sha
         print(f"{filename} EXISTS")
     except Exception as e:
@@ -153,16 +185,23 @@ def update_file(repo, filename, branch=None):
 
 
 @retry(exceptions=Exception, tries=3, delay=2, backoff=2)
-def delete_file(repo, filename):
+def delete_file(repo, filename, branch=None):
     """
     刪除指定的 Github 倉庫中的檔案
     """
     all_files = []
-    contents = repo.get_contents("")
+    if branch:
+        contents = repo.get_contents("", ref=branch)
+    else:
+        contents = repo.get_contents("")
+
     while contents:
         file_content = contents.pop(0)
         if file_content.type == "dir":
-            contents.extend(repo.get_contents(file_content.path))
+            if branch:
+                contents.extend(repo.get_contents(file_content.path, ref=branch))
+            else:
+                contents.extend(repo.get_contents(file_content.path))
         else:
             file = file_content
             all_files.append(file.path)
@@ -172,8 +211,12 @@ def delete_file(repo, filename):
 
     if git_file in all_files:
         # 如果已存在，刪除檔案
-        file = repo.get_contents(git_file)
-        repo.delete_file(file.path, "Delete files", file.sha)
+        if branch:
+            file = repo.get_contents(git_file, ref=branch)
+            repo.delete_file(file.path, "Delete files", file.sha, branch=branch)
+        else:
+            file = repo.get_contents(git_file)
+            repo.delete_file(file.path, "Delete files", file.sha)
         print(f"{git_file} deleted")
     else:
         print(f"{git_file} does not exist.")
