@@ -1,3 +1,4 @@
+import platform
 import os
 import signal
 import sys
@@ -5,6 +6,8 @@ import sys
 
 class Watcher:
     def __init__(self):
+        if not platform.system().lower() == "linux":
+            sys.exit("Watcher only works on Linux")
         self.child = os.fork()
         if self.child == 0:
             return
